"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateIcoFromPNGs = void 0;
var icoHeaderSize = 6;
var icodirectorySize = 16;
var dibHeaderSize = 40;
var createICONDIR = function (numImages) {
    var buf = Buffer.alloc(icoHeaderSize);
    buf.writeUInt16LE(0, 0);
    buf.writeUInt16LE(1, 2);
    buf.writeUInt16LE(numImages, 4);
    return buf;
};
var createICONDIRENTRY = function (png, offset) {
    var buf = Buffer.alloc(icodirectorySize);
    var width = png.image.width == 256 ? 0 : png.image.width;
    var height = png.image.height == 256 ? 0 : png.image.height;
    var bpp = png.metadata.bpp * 8;
    var size = png.image.data.length + dibHeaderSize;
    buf.writeUInt8(width, 0);
    buf.writeUInt8(height, 1);
    buf.writeUInt8(0, 2);
    buf.writeUInt8(0, 3);
    buf.writeUInt16LE(1, 4);
    buf.writeUInt16LE(bpp, 6);
    buf.writeUInt32LE(size, 8);
    buf.writeUInt32LE(offset, 12);
    return buf;
};
var createDIBInfoHeader = function (png) {
    var buf = Buffer.alloc(dibHeaderSize);
    buf.writeUInt32LE(dibHeaderSize, 0);
    buf.writeInt32LE(png.image.width, 4);
    buf.writeInt32LE(png.image.height * 2, 8);
    buf.writeUInt16LE(1, 12);
    buf.writeUInt16LE(png.metadata.bpp * 8, 14);
    buf.writeUInt32LE(0, 16);
    buf.writeUInt32LE(png.image.data.length, 20);
    buf.writeInt32LE(0, 24);
    buf.writeInt32LE(0, 28);
    buf.writeUInt32LE(0, 32);
    buf.writeUInt32LE(0, 36);
    return buf;
};
var createDIBPixelArray = function (png) {
    var bpp = png.metadata.bpp;
    var numCols = png.image.width * bpp;
    var numRows = png.image.height * numCols;
    var end = numRows - numCols;
    var buf = Buffer.alloc(png.image.data.length);
    for (var r = 0; r < numRows; r += numCols) {
        for (var c = 0; c < numCols; c += bpp) {
            var pos = r + c;
            var red = png.image.data.readUint8(pos);
            var green = png.image.data.readUint8(pos + 1);
            var blue = png.image.data.readUint8(pos + 2);
            var alpha = png.image.data.readUint8(pos + 3);
            pos = end - r + c;
            buf.writeUint8(blue, pos);
            buf.writeUint8(green, pos + 1);
            buf.writeUint8(red, pos + 2);
            buf.writeUint8(alpha, pos + 3);
        }
    }
    return buf;
};
function generateIcoFromPNGs(pngs) {
    var numImages = pngs.length;
    var header = createICONDIR(numImages);
    var bufArray = [header];
    var len = header.length;
    var offset = icoHeaderSize + icodirectorySize * numImages;
    for (var i = 0; i < numImages; i++) {
        var png = pngs[i];
        var icoDir = createICONDIRENTRY(png, offset);
        bufArray.push(icoDir);
        len += icoDir.length;
        offset += png.image.data.length + dibHeaderSize;
    }
    for (var i = 0; i < numImages; i++) {
        var png = pngs[i];
        var infoHeader = createDIBInfoHeader(png);
        var pixelArray = createDIBPixelArray(png);
        bufArray.push(infoHeader, pixelArray);
        len += infoHeader.length + pixelArray.length;
    }
    return Buffer.concat(bufArray, len);
}
exports.generateIcoFromPNGs = generateIcoFromPNGs;
//# sourceMappingURL=generateIco.js.map