import { __awaiter, __generator } from "tslib";
import sizeOf from 'image-size';
import * as jimp from 'jimp';
export function resizePng(imageBuffer, options) {
    return __awaiter(this, void 0, void 0, function () {
        var image;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4, jimp.read(imageBuffer)];
                case 1:
                    image = _a.sent();
                    if (typeof options.width !== 'number') {
                        options.width = Math.trunc(image.bitmap.width * (options.height / image.bitmap.height));
                    }
                    if (typeof options.height !== 'number') {
                        options.height = Math.trunc(image.bitmap.height * (options.width / image.bitmap.width));
                    }
                    return [2, image
                            .resize(options.width, options.height)
                            .getBufferAsync(jimp.MIME_PNG)];
            }
        });
    });
}
export function resizeLargestPng(images, imageSizes) {
    return __awaiter(this, void 0, void 0, function () {
        var largestImage;
        return __generator(this, function (_a) {
            largestImage = images
                .map(function (i) {
                var _a = sizeOf(i), width = _a.width, height = _a.height;
                return {
                    image: i,
                    width: width,
                    height: height,
                };
            })
                .reduce(function (a, b) {
                if (typeof a.width !== 'number') {
                    return b;
                }
                if (typeof b.width !== 'number') {
                    return a;
                }
                if (a.width > b.width) {
                    return a;
                }
                else {
                    return b;
                }
            }, { width: 0, height: 0, image: Buffer.alloc(0) });
            return [2, Promise.all(imageSizes
                    .filter(function (s) { return s <= largestImage.width; })
                    .map(function (targetSize) {
                    return resizePng(largestImage.image, {
                        width: targetSize,
                        height: targetSize,
                    });
                }))];
        });
    });
}
//# sourceMappingURL=resizePng.js.map